
using System;
using System.Threading;
using System.Reflection;
using System.Collections.Generic;

// __________  implementation  ____________________________________

/** Create and modify a spreadsheet view.
 */
public class ViewSample : SpreadsheetDocHelper
{
    const string CHART_CLASS_ID = "12DCAE26-281F-416F-a234-c3086127382e";

    [STAThread]
    public static void Main( String [] args )
    {
        try
        {
            using ( ViewSample aSample = new ViewSample( args ) )
            {
                aSample.doSampleFunction();
            }
            Console.WriteLine( "\nSamples done." );
        }
        catch (Exception ex)
        {
            Console.WriteLine( "Sample caught exception! " + ex );
        }
    }

// ________________________________________________________________

    public ViewSample( String[] args )
        : base( args )
    {
    }
    
// ________________________________________________________________

    /** This sample function performs all changes on the view. */
    public void doSampleFunction()
    {
        unoidl.com.sun.star.sheet.XSpreadsheetDocument xDoc = getDocument();
        unoidl.com.sun.star.frame.XModel xModel =
            (unoidl.com.sun.star.frame.XModel)xDoc;
        unoidl.com.sun.star.frame.XController xController =
            xModel.getCurrentController();

        unoidl.com.sun.star.sheet.XSpreadsheetView xView =
               (unoidl.com.sun.star.sheet.XSpreadsheetView)xController;
        

       unoidl.com.sun.star.sheet.XSpreadsheet xSheet =
            xView.getActiveSheet();

        unoidl.com.sun.star.table.XTableChartsSupplier aSheet;
        unoidl.com.sun.star.table.CellRangeAddress[] aAddresses = null;
        string sChartName = "Chart Testing";

        aSheet = (unoidl.com.sun.star.table.XTableChartsSupplier)xSheet;

        if (aSheet != null)
            Console.WriteLine("Got aSheet!");

        unoidl.com.sun.star.chart.XChartDocument aChartDocument = null;


        unoidl.com.sun.star.table.XTableCharts aChartCollection = aSheet.getCharts();

        unoidl.com.sun.star.container.XNameAccess aChartCollectionNA = (unoidl.com.sun.star.container.XNameAccess)aChartCollection;


        // only insert the chart if it does not already exist 

        if (aChartCollectionNA != null && !aChartCollectionNA.hasByName(sChartName))
        {

            unoidl.com.sun.star.awt.Rectangle aRect = new unoidl.com.sun.star.awt.Rectangle(1000, 1000, 15000, 9271);

            aChartCollection.addNewByName(sChartName, aRect, aAddresses, true, false);

            try
            {

                unoidl.com.sun.star.table.XTableChart aTableChart = (unoidl.com.sun.star.table.XTableChart)
                        aChartCollectionNA.getByName(sChartName).Value;


                // the table chart is an embedded object which contains the chart document
                object oChartDocument = ((unoidl.com.sun.star.document.XEmbeddedObjectSupplier)aTableChart).getEmbeddedObject();

                aChartDocument = (unoidl.com.sun.star.chart.XChartDocument)oChartDocument;

                unoidl.com.sun.star.lang.XMultiServiceFactory aFact = (unoidl.com.sun.star.lang.XMultiServiceFactory)getServiceManager();

                unoidl.com.sun.star.chart.XDiagram aDiagram = (unoidl.com.sun.star.chart.XDiagram)((unoidl.com.sun.star.lang.XMultiServiceFactory)aChartDocument).createInstance("com.sun.star.chart.BarDiagram");
               

                aChartDocument.setDiagram(aDiagram);

                unoidl.com.sun.star.beans.XPropertySet titlePropSet = (unoidl.com.sun.star.beans.XPropertySet)aChartDocument.getTitle();

                //This one works
                titlePropSet.setPropertyValue("String", new uno.Any("Just Another Title"));
                //Try and set the char height of the title
                //it won't work unless chart is in edit mode
                titlePropSet.setPropertyValue("CharHeight", new uno.Any(14));
            }
            catch (unoidl.com.sun.star.container.NoSuchElementException ex)
            {
                Console.WriteLine("Couldn't find chart with name " + sChartName + ": " + ex);
            }

        }
    }

// ________________________________________________________________

    //  listener to react on finished selection

    private class ExampleRangeListener
        : unoidl.com.sun.star.sheet.XRangeSelectionListener
    {
        public String aResult;

        public void done( unoidl.com.sun.star.sheet.RangeSelectionEvent aEvent )
        {
            aResult = aEvent.RangeDescriptor;
            Monitor.Enter( this );
            try
            {
                Monitor.Pulse( this );
            }
            finally
            {
                Monitor.Exit( this );
            }
        }

        public void aborted(
            unoidl.com.sun.star.sheet.RangeSelectionEvent aEvent )
        {
            Monitor.Enter( this );
            try
            {
                Monitor.Pulse( this );
            }
            finally
            {
                Monitor.Exit( this );
            }
        }

        public void disposing( unoidl.com.sun.star.lang.EventObject aObj )
        {
        }
    }

// ________________________________________________________________

}
